%define major	%{version}
%define libname	%mklibname %{name}_ %{major}
%define devname	%mklibname %{name} -d

# third party tree-sitter and radare2-shell-parser
# needed commit can be found in meson.build (line: TS_TIP and line: SHELLPARSER_TIP)
%define sitter_commit	de8877db35ecaf7f8dd8d751b07ad9d634fb6a91
%define parser_commit	4bc342424550e02879722716a65a4c0d46344845

Name:		radare2
Version:	4.2.1
Release:	%mkrel 1
Summary:	Reverse engineering framework and commandline tools security
License:	GPLv3+ and LGPLv3+
Group:		System/Libraries
Url:		http://www.radare.org/
Source0:	https://github.com/radare/radare2/archive/%{version}/%{name}-%{version}.tar.gz
Source1:	https://github.com/tree-sitter/tree-sitter/archive/%{sitter_commit}.tar.gz
Source2:	https://github.com/ret2libc/radare2-shell-parser/archive/%{parser_commit}.tar.gz

BuildRequires:	file-devel
BuildRequires:	gmp-devel
BuildRequires:	meson
BuildRequires:	pkgconfig(bzip2)
BuildRequires:	pkgconfig(capstone)
BuildRequires:	pkgconfig(libuv)
BuildRequires:	pkgconfig(liblz4)
BuildRequires:	pkgconfig(libzip)
BuildRequires:	pkgconfig(openssl) >= 1.1
BuildRequires:	pkgconfig(zlib)

%description
Radare2 is a rewrite from scratch of radare in order to provide a set
of libraries and tools to work with binary files.

Radare project started as a forensics tool, a scriptable commandline
hexadecimal editor able to open disk files, but later support for
analyzing binaries, disassembling code, debugging programs, attaching
to remote gdb servers, ...

#------------------------------------------------

%package -n	%{libname}
Summary:	Reverse engineering framework and commandline tools security
Group:		System/Libraries

%description -n	%{libname}
Radare2 is a rewrite from scratch of radare in order to provide a set
of libraries and tools to work with binary files.

Radare project started as a forensics tool, a scriptable commandline
hexadecimal editor able to open disk files, but later support for
analyzing binaries, disassembling code, debugging programs, attaching
to remote gdb servers, ...

#------------------------------------------------

%package -n	%{devname}
Summary:	Development package for %{name}
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{devname}
Header files for development with %{name}.

#------------------------------------------------


%prep
%setup -q -a1 -a2
%autopatch -p1

# prepare third party tree-sitter and radare2-shell-parser
mkdir -p build/shlr
mv tree-sitter-%{sitter_commit} ./build/shlr/tree-sitter
mv radare2-shell-parser-%{parser_commit} ./build/shlr/radare2-shell-parser

%build
# Whereever possible use the system-wide libraries instead of bundles
%meson \
    -Duse_sys_magic=false \
    -Duse_sys_zip=true \
    -Duse_sys_zlib=true \
    -Duse_sys_lz4=true \
    -Duse_sys_xxhash=false \
    -Duse_sys_openssl=true \
    -Duse_libuv=true \
    -Duse_sys_capstone=true
%meson_build

%install
%meson_install

# create r2 symlink because meson build does not create it (yet)
ln -s radare2 %{buildroot}%{_bindir}/r2

%files
%doc AUTHORS.md CONTRIBUTING.md DEVELOPERS.md README.md
%license COPYING
%{_bindir}/r2
%{_bindir}/r2agent
%{_bindir}/r2pm
%{_bindir}/rabin2
%{_bindir}/radare2
%{_bindir}/radiff2
%{_bindir}/rafind2
%{_bindir}/ragg2
%{_bindir}/rahash2
%{_bindir}/rarun2
%{_bindir}/rasm2
%{_bindir}/rax2
%{_datadir}/%{name}/
%{_datadir}/zsh/site-functions/_r*
%{_docdir}/%{name}/
%{_mandir}/man1/r*.1.*
%{_mandir}/man7/esil.7.*

%files -n %{libname}
%{_libdir}/libr*.so.%{major}

%files -n %{devname}
%{_includedir}/libr/
%{_libdir}/libr*.so
%{_libdir}/pkgconfig/*.pc


%changelog
* Fri Feb 21 2020 daviddavid <daviddavid> 4.2.1-1.mga7
+ Revision: 1548515
- new version: 4.2.1, fixes CVE-2019-19590 and CVE-2019-19647 (mga#26232)
- new version: 3.9.0, fixes more some security issues (mga#25933)
- new version: 3.8.0, fixes CVE-2019-14745 (mga#25933)
- new version: 3.6.0, fixes CVE-2019-12790, CVE-2019-12802, CVE-2019-12865 (mga#25933)

* Thu Apr 18 2019 daviddavid <daviddavid> 3.4.1-1.mga7
+ Revision: 1393120
- new version: 3.4.1

* Thu Apr 18 2019 umeabot <umeabot> 3.3.0-2.mga7
+ Revision: 1392913
- Rebuild with meson 0.50.1

* Mon Feb 25 2019 daviddavid <daviddavid> 3.3.0-1.mga7
+ Revision: 1370017
- new version: 3.3.0

* Tue Jan 22 2019 daviddavid <daviddavid> 3.2.1-1.mga7
+ Revision: 1359451
- new version: 3.2.1

* Mon Jan 14 2019 daviddavid <daviddavid> 3.2.0-3.mga7
+ Revision: 1356392
- use bundled radare2 magic libraries until an upstream radare2-cutter fix
  * https://github.com/radareorg/cutter/issues/1108

* Sun Jan 13 2019 daviddavid <daviddavid> 3.2.0-2.mga7
+ Revision: 1355887
- new version: 3.2.0
- switch to meson build system

* Sat Jan 12 2019 tv <tv> 2.9.0-2.mga7
+ Revision: 1355779
- rebuild for new capstone

* Thu Sep 06 2018 daviddavid <daviddavid> 2.9.0-1.mga7
+ Revision: 1257555
- new version: 2.9.0

* Tue Aug 14 2018 daviddavid <daviddavid> 2.8.0-1.mga7
+ Revision: 1251442
- new version: 2.8.0

* Wed Jul 11 2018 daviddavid <daviddavid> 2.7.0-1.mga7
+ Revision: 1243092
- new version: 2.7.0

* Thu Jul 05 2018 daviddavid <daviddavid> 2.6.9-1.mga7
+ Revision: 1241725
- new version: 2.6.9

* Sun May 20 2018 daviddavid <daviddavid> 2.5.0-1.mga7
+ Revision: 1230585
- initial package radare2

